aboutsummaryrefslogtreecommitdiffstats
path: root/epan/dissectors/packet-catapult-dct2000.c
diff options
context:
space:
mode:
authorGuy Harris <guy@alum.mit.edu>2016-08-24 19:23:09 -0700
committerGuy Harris <guy@alum.mit.edu>2016-08-25 02:24:08 +0000
commit8ce301704bb191208ea2486396d83c4305ba3315 (patch)
treee737fe8c948e9a28b8939ead494bebaa8432f03b /epan/dissectors/packet-catapult-dct2000.c
parentb66fb7d3d34f1671963bc19ec9ece2eaecf391b5 (diff)
Expand comments.
Change-Id: I4e3de542d24c567434f4554917e826ccbd64cb6c Reviewed-on: https://code.wireshark.org/review/17319 Reviewed-by: Guy Harris <guy@alum.mit.edu>
Diffstat (limited to 'epan/dissectors/packet-catapult-dct2000.c')
-rw-r--r--epan/dissectors/packet-catapult-dct2000.c14
1 files changed, 11 insertions, 3 deletions
diff --git a/epan/dissectors/packet-catapult-dct2000.c b/epan/dissectors/packet-catapult-dct2000.c
index 743019b9e8..29abf7722d 100644
--- a/epan/dissectors/packet-catapult-dct2000.c
+++ b/epan/dissectors/packet-catapult-dct2000.c
@@ -1026,7 +1026,12 @@ static void dissect_rrc_lte(tvbuff_t *tvb, gint offset,
/* Dissect an CCPRI LTE frame by first parsing the header entries then passing
- the data to the CPRI C&M dissector */
+ the data to the CPRI C&M dissector
+
+ XXX - is this the Common Public Radio Interface? If so, what's the extra
+ "C" in "CCPRI"? And why is the LAPB dissector involved here? The CPRI
+ spec just speaks of HDLC; LAPB is certainly a HDLC-based protocol, but
+ that doesn't mean every HDLC-based protocol is LAPB. */
static void dissect_ccpri_lte(tvbuff_t *tvb, gint offset,
packet_info *pinfo, proto_tree *tree)
{
@@ -1077,8 +1082,11 @@ static void dissect_ccpri_lte(tvbuff_t *tvb, gint offset,
length = tvb_get_ntohs(tvb, offset);
offset += 2;
- /* Send remainder to lapb dissector (lapb needs patch with preference
- set to call cpri C&M dissector instead of X.25) */
+ /* Send remainder to lapb dissector; I assume "CPRI" is the Common
+ Public Radio Interface, in which case the "lapb" dissector is
+ being used to dissect the HDLC used by CPRI, and in which case
+ we should really have a CPRI dissector that dissects its HDLC
+ and then hands off to a CPRI C&M dissector. */
protocol_handle = find_dissector("lapb");
if ((protocol_handle != NULL) && (tvb_reported_length_remaining(tvb, offset) > 0)) {
ccpri_tvb = tvb_new_subset_length(tvb, offset, length);